---
title: Baker Farm
id: baker-farm
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 10
kind: article
---

## Baker Farm

Sometimes I rambled to pine groves, standing like temples, or like
fleets at sea, full-rigged, with wavy boughs, and rippling with light,
so soft and green and shady that the Druids would have forsaken their
oaks to worship in them; or to the cedar wood beyond Flint’s Pond,
where the trees, covered with hoary blue berries, spiring higher and
higher, are fit to stand before Valhalla, and the creeping juniper
covers the ground with wreaths full of fruit; or to swamps where the
usnea lichen hangs in festoons from the white-spruce trees, and
toad-stools, round tables of the swamp gods, cover the ground, and more
beautiful fungi adorn the stumps, like butterflies or shells, vegetable
winkles; where the swamp-pink and dogwood grow, the red alder-berry
glows like eyes of imps, the waxwork grooves and crushes the hardest
woods in its folds, and the wild-holly berries make the beholder forget
his home with their beauty, and he is dazzled and tempted by nameless
other wild forbidden fruits, too fair for mortal taste. Instead of
calling on some scholar, I paid many a visit to particular trees, of
kinds which are rare in this neighborhood, standing far away in the
middle of some pasture, or in the depths of a wood or swamp, or on a
hill-top; such as the black-birch, of which we have some handsome
specimens two feet in diameter; its cousin, the yellow birch, with its
loose golden vest, perfumed like the first; the beech, which has so
neat a bole and beautifully lichen-painted, perfect in all its details,
of which, excepting scattered specimens, I know but one small grove of
sizable trees left in the township, supposed by some to have been
planted by the pigeons that were once baited with beech nuts near by;
it is worth the while to see the silver grain sparkle when you split
this wood; the bass; the hornbeam; the _Celtis occidentalis_, or false
elm, of which we have but one well-grown; some taller mast of a pine, a
shingle tree, or a more perfect hemlock than usual, standing like a
pagoda in the midst of the woods; and many others I could mention.
These were the shrines I visited both summer and winter.

Once it chanced that I stood in the very abutment of a rainbow’s arch,
which filled the lower stratum of the atmosphere, tinging the grass and
leaves around, and dazzling me as if I looked through colored crystal.
It was a lake of rainbow light, in which, for a short while, I lived
like a dolphin. If it had lasted longer it might have tinged my
employments and life. As I walked on the railroad causeway, I used to
wonder at the halo of light around my shadow, and would fain fancy
myself one of the elect. One who visited me declared that the shadows
of some Irishmen before him had no halo about them, that it was only
natives that were so distinguished. Benvenuto Cellini tells us in his
memoirs, that, after a certain terrible dream or vision which he had
during his confinement in the castle of St. Angelo, a resplendent light
appeared over the shadow of his head at morning and evening, whether he
was in Italy or France, and it was particularly conspicuous when the
grass was moist with dew. This was probably the same phenomenon to
which I have referred, which is especially observed in the morning, but
also at other times, and even by moonlight. Though a constant one, it
is not commonly noticed, and, in the case of an excitable imagination
like Cellini’s, it would be basis enough for superstition. Beside, he
tells us that he showed it to very few. But are they not indeed
distinguished who are conscious that they are regarded at all?



I set out one afternoon to go a-fishing to Fair-Haven, through the
woods, to eke out my scanty fare of vegetables. My way led through
Pleasant Meadow, an adjunct of the Baker Farm, that retreat of which a
poet has since sung, beginning,—

     “Thy entry is a pleasant field,
     Which some mossy fruit trees yield
     Partly to a ruddy brook,
     By gliding musquash undertook,
     And mercurial trout,
     Darting about.”

I thought of living there before I went to Walden. I “hooked” the
apples, leaped the brook, and scared the musquash and the trout. It was
one of those afternoons which seem indefinitely long before one, in
which many events may happen, a large portion of our natural life,
though it was already half spent when I started. By the way there came
up a shower, which compelled me to stand half an hour under a pine,
piling boughs over my head, and wearing my handkerchief for a shed; and
when at length I had made one cast over the pickerel-weed, standing up
to my middle in water, I found myself suddenly in the shadow of a
cloud, and the thunder began to rumble with such emphasis that I could
do no more than listen to it. The gods must be proud, thought I, with
such forked flashes to rout a poor unarmed fisherman. So I made haste
for shelter to the nearest hut, which stood half a mile from any road,
but so much the nearer to the pond, and had long been uninhabited:—

     “And here a poet builded,
         In the completed years,
     For behold a trivial cabin
         That to destruction steers.”

So the Muse fables. But therein, as I found, dwelt now John Field, an
Irishman, and his wife, and several children, from the broad-faced boy
who assisted his father at his work, and now came running by his side
from the bog to escape the rain, to the wrinkled, sibyl-like,
cone-headed infant that sat upon its father’s knee as in the palaces of
nobles, and looked out from its home in the midst of wet and hunger
inquisitively upon the stranger, with the privilege of infancy, not
knowing but it was the last of a noble line, and the hope and cynosure
of the world, instead of John Field’s poor starveling brat. There we
sat together under that part of the roof which leaked the least, while
it showered and thundered without. I had sat there many times of old
before the ship was built that floated his family to America. An
honest, hard-working, but shiftless man plainly was John Field; and his
wife, she too was brave to cook so many successive dinners in the
recesses of that lofty stove; with round greasy face and bare breast,
still thinking to improve her condition one day; with the never absent
mop in one hand, and yet no effects of it visible anywhere. The
chickens, which had also taken shelter here from the rain, stalked
about the room like members of the family, too humanized methought to
roast well. They stood and looked in my eye or pecked at my shoe
significantly. Meanwhile my host told me his story, how hard he worked
“bogging” for a neighboring farmer, turning up a meadow with a spade or
bog hoe at the rate of ten dollars an acre and the use of the land with
manure for one year, and his little broad-faced son worked cheerfully
at his father’s side the while, not knowing how poor a bargain the
latter had made. I tried to help him with my experience, telling him
that he was one of my nearest neighbors, and that I too, who came
a-fishing here, and looked like a loafer, was getting my living like
himself; that I lived in a tight, light, and clean house, which hardly
cost more than the annual rent of such a ruin as his commonly amounts
to; and how, if he chose, he might in a month or two build himself a
palace of his own; that I did not use tea, nor coffee, nor butter, nor
milk, nor fresh meat, and so did not have to work to get them; again,
as I did not work hard, I did not have to eat hard, and it cost me but
a trifle for my food; but as he began with tea, and coffee, and butter,
and milk, and beef, he had to work hard to pay for them, and when he
had worked hard he had to eat hard again to repair the waste of his
system,—and so it was as broad as it was long, indeed it was broader
than it was long, for he was discontented and wasted his life into the
bargain; and yet he had rated it as a gain in coming to America, that
here you could get tea, and coffee, and meat every day. But the only
true America is that country where you are at liberty to pursue such a
mode of life as may enable you to do without these, and where the state
does not endeavor to compel you to sustain the slavery and war and
other superfluous expenses which directly or indirectly result from the
use of such things. For I purposely talked to him as if he were a
philosopher, or desired to be one. I should be glad if all the meadows
on the earth were left in a wild state, if that were the consequence of
men’s beginning to redeem themselves. A man will not need to study
history to find out what is best for his own culture. But alas! the
culture of an Irishman is an enterprise to be undertaken with a sort of
moral bog hoe. I told him, that as he worked so hard at bogging, he
required thick boots and stout clothing, which yet were soon soiled and
worn out, but I wore light shoes and thin clothing, which cost not half
so much, though he might think that I was dressed like a gentleman,
(which, however, was not the case,) and in an hour or two, without
labor, but as a recreation, I could, if I wished, catch as many fish as
I should want for two days, or earn enough money to support me a week.
If he and his family would live simply, they might all go
a-huckleberrying in the summer for their amusement. John heaved a sigh
at this, and his wife stared with arms a-kimbo, and both appeared to be
wondering if they had capital enough to begin such a course with, or
arithmetic enough to carry it through. It was sailing by dead reckoning
to them, and they saw not clearly how to make their port so; therefore
I suppose they still take life bravely, after their fashion, face to
face, giving it tooth and nail, not having skill to split its massive
columns with any fine entering wedge, and rout it in detail;—thinking
to deal with it roughly, as one should handle a thistle. But they fight
at an overwhelming disadvantage,—living, John Field, alas! without
arithmetic, and failing so.

“Do you ever fish?” I asked. “Oh yes, I catch a mess now and then when
I am lying by; good perch I catch.” “What’s your bait?” “I catch
shiners with fish-worms, and bait the perch with them.” “You’d better
go now, John,” said his wife, with glistening and hopeful face; but
John demurred.

The shower was now over, and a rainbow above the eastern woods promised
a fair evening; so I took my departure. When I had got without I asked
for a drink, hoping to get a sight of the well bottom, to complete my
survey of the premises; but there, alas! are shallows and quicksands,
and rope broken withal, and bucket irrecoverable. Meanwhile the right
culinary vessel was selected, water was seemingly distilled, and after
consultation and long delay passed out to the thirsty one,—not yet
suffered to cool, not yet to settle. Such gruel sustains life here, I
thought; so, shutting my eyes, and excluding the motes by a skilfully
directed under-current, I drank to genuine hospitality the heartiest
draught I could. I am not squeamish in such cases when manners are
concerned.

As I was leaving the Irishman’s roof after the rain, bending my steps
again to the pond, my haste to catch pickerel, wading in retired
meadows, in sloughs and bog-holes, in forlorn and savage places,
appeared for an instant trivial to me who had been sent to school and
college; but as I ran down the hill toward the reddening west, with the
rainbow over my shoulder, and some faint tinkling sounds borne to my
ear through the cleansed air, from I know not what quarter, my Good
Genius seemed to say,—Go fish and hunt far and wide day by day,—farther
and wider,—and rest thee by many brooks and hearth-sides without
misgiving. Remember thy Creator in the days of thy youth. Rise free
from care before the dawn, and seek adventures. Let the noon find thee
by other lakes, and the night overtake thee everywhere at home. There
are no larger fields than these, no worthier games than may here be
played. Grow wild according to thy nature, like these sedges and
brakes, which will never become English hay. Let the thunder rumble;
what if it threaten ruin to farmers’ crops? that is not its errand to
thee. Take shelter under the cloud, while they flee to carts and sheds.
Let not to get a living be thy trade, but thy sport. Enjoy the land,
but own it not. Through want of enterprise and faith men are where they
are, buying and selling, and spending their lives like serfs.

O Baker Farm!

     “Landscape where the richest element
     Is a little sunshine innocent.” * *

     “No one runs to revel
     On thy rail-fenced lea.” * *

     “Debate with no man hast thou,
         With questions art never perplexed,
     As tame at the first sight as now,
         In thy plain russet gabardine dressed.” * *

     “Come ye who love,
         And ye who hate,
     Children of the Holy Dove,
         And Guy Faux of the state,
     And hang conspiracies
     From the tough rafters of the trees!”

Men come tamely home at night only from the next field or street, where
their household echoes haunt, and their life pines because it breathes
its own breath over again; their shadows morning and evening reach
farther than their daily steps. We should come home from far, from
adventures, and perils, and discoveries every day, with new experience
and character.

Before I had reached the pond some fresh impulse had brought out John
Field, with altered mind, letting go “bogging” ere this sunset. But he,
poor man, disturbed only a couple of fins while I was catching a fair
string, and he said it was his luck; but when we changed seats in the
boat luck changed seats too. Poor John Field!—I trust he does not read
this, unless he will improve by it,—thinking to live by some derivative
old country mode in this primitive new country,—to catch perch with
shiners. It is good bait sometimes, I allow. With his horizon all his
own, yet he a poor man, born to be poor, with his inherited Irish
poverty or poor life, his Adam’s grandmother and boggy ways, not to
rise in this world, he nor his posterity, till their wading webbed
bog-trotting feet get _talaria_ to their heels.


